@@ -39,3 +39,21 @@ getgoversion(void)
 {
 	return GOVERSION;
 }
+
+char*
+getgoarm(void)
+{
+	return defgetenv("GOARM", GOARM);
+}
+
+char*
+getgo386(void)
+{
+	return defgetenv("GO386", GO386);
+}
+
+char *
+getgoextlinkenabled(void)
+{
+	return GO_EXTLINK_ENABLED;
+}
